@@ -27,15 +27,4 @@ options = (
             "level": 2,
         },
     ),
-    (
-        "api-server-name",
-        {
-            "type": "string",
-            "default": None,
-            "help": "The base url to use for openapi validation. "
-            "Set this to the CubicWeb base url if openapi cannot find the server.",
-            "group": "api",
-            "level": 2,
-        },
-    ),
 )
