@@ -18,7 +18,6 @@ from typing import Union
 
 from cubicweb import ConfigurationError
 from cubicweb.pyramid.config import AllInOneConfiguration
-from cubicweb.pyramid.core import CubicWebPyramidRequest
 from cubicweb.server.repository import Repository
 from pyramid.config import Configurator
 from pyramid.request import Request
@@ -27,16 +26,6 @@ from cubicweb_api.api_transaction import ApiTransactionsRepository
 from cubicweb_api.constants import API_PATH_DEFAULT_PREFIX
 
 
-def get_cw_request(request: Request) -> CubicWebPyramidRequest:
-    """
-    Helper used to have typing on the cw_request object.
-
-    :param request: The pyramid request containing the CubicWeb request
-    :return: A CubicWebPyramidRequest object
-    """
-    return request.cw_request
-
-
 def get_cw_repo(req_or_conf: Union[Request, Configurator]) -> Repository:
     """
     Helper used to have typing on the CubicWeb repository.
@@ -54,7 +43,7 @@ def get_cw_all_in_one_config(config: Configurator) -> AllInOneConfiguration:
     :param config: A pyramid configurator object
     :return: A AllInOneConfiguration object
     """
-    return get_cw_repo(config).config
+    return config.registry["cubicweb.config"]
 
 
 def get_transactions_repository(request: Request) -> ApiTransactionsRepository:
@@ -67,7 +56,7 @@ def get_transactions_repository(request: Request) -> ApiTransactionsRepository:
     return get_cw_repo(request).api_transactions
 
 
-def get_api_server_base(config: Configurator) -> str:
+def get_openapi_spec_server_url(config: Configurator) -> str:
     """
     Gets the server base url from the configuration.
     If no configuration is found, fallback to the CubicWeb base url
@@ -76,23 +65,10 @@ def get_api_server_base(config: Configurator) -> str:
     :return: The configured server name or the CubicWeb base url
     :raise ConfigurationError if the name set in config is not valid
     """
-    repo = get_cw_repo(config)
-    with repo.internal_cnx() as cnx:
-        server_name: str = repo.get_option_value("api-server-name") or cnx.base_url()
-    match = re.match("^[a-zA-Z0-9-_@.&+!*(),/:]{1,60}$", server_name)
-    if match:
-        return server_name
-    else:
-        if len(server_name) > 60:
-            raise ConfigurationError(
-                f"api-server-name '{server_name}' is too long. "
-                "Max size allowed is 60 characters. "
-                f"Current size is {len(server_name)}."
-            )
-        raise ConfigurationError(
-            f"api-server-name '{server_name}' contains invalid characters. "
-            "Allowed characters are: a-zA-Z0-9-_@.&+!*(),/:"
-        )
+    cwconfig = get_cw_all_in_one_config(config)
+    server_url: str = cwconfig.option_value("base-url")
+    server_url += get_api_path_prefix(config)
+    return server_url
 
 
 def get_api_path_prefix(config: Configurator) -> str:
@@ -107,10 +83,10 @@ def get_api_path_prefix(config: Configurator) -> str:
     repo = get_cw_repo(config)
     path_prefix: str = (
         repo.get_option_value("api-path-prefix") or API_PATH_DEFAULT_PREFIX
-    )
-    match = re.match("^/[a-zA-Z0-9-_@.&+!*(),/]{1,29}$", path_prefix)
+    ).strip("/")
+    match = re.match("^[a-zA-Z0-9-_@.&+!*(),/]{1,29}$", path_prefix)
     if match:
-        return f"{path_prefix.rstrip('/')}/v1"
+        return f"{path_prefix}/v1"
     else:
         if len(path_prefix) > 30:
             raise ConfigurationError(
@@ -118,11 +94,6 @@ def get_api_path_prefix(config: Configurator) -> str:
                 "Max size allowed is 30 characters. "
                 f"Current size is {len(path_prefix)}."
             )
-        if not path_prefix.startswith("/"):
-            raise ConfigurationError(
-                f"api-path-prefix '{path_prefix}' does not start with '/'. "
-                "Prefix should start with '/' to be validated by openapi"
-            )
 
         raise ConfigurationError(
             f"api-path-prefix '{path_prefix}' contains invalid characters. "
